FDBA class abstract

Implementers

Constructors

FDBA(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastId ↔ int
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tables → Future<List<MP>>
no setter

Methods

connect() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, [List<Object?> parameters = const []]) → Future<bool>
select(String sql, [List<Object?> parameters = const []]) → Future<List<MP>>
store(FTransactionParams transaction) → Future<bool>
tableIndexes(String name) → Future<List<MP>>
tableInfo(String name) → Future<List<MP>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited