AsyncDatabase class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Closes this database and releases associated resources.
-
execute(
String sql, [List< Object?> parameters = const []]) → Future<void> -
Executes the
sqlstatement with the providedparametersand ignores the result. -
getLastInsertRowId(
) → Future< int> - Returns the row id of the last inserted row.
-
getUserVersion(
) → Future< int> - Returns the application defined version of this database.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
String sql, [List< Object?> parameters = const []]) → Future<ResultSet> -
Prepares the
sqlselect statement and runs it with the providedparameters. -
sendCommand(
String type, {dynamic body}) → Future -
setUserVersion(
int value) → Future< void> - Set the application defined version of this database.
-
store(
FTransactionParams transaction) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
transaction(
FTransactionParams transaction) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited