AsyncDatabaseCommand class

Constructors

AsyncDatabaseCommand(String type, SendPort sendPort, {dynamic body, bool isError = false})
const

Properties

body → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendPort SendPort
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited