WebFDB class

Inheritance

Constructors

WebFDB(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
lastId int
getter/setter pairinherited
name String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables Future<List<MP>>
no setterinherited

Methods

connect() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>
override
select(String sql, [List<Object?> parameters = const []]) Future<List<MP>>
override
store(FTransactionParams params) Future<bool>
override
tableIndexes(String name) Future<List<MP>>
inherited
tableInfo(String name) Future<List<MP>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited