PulseF class

Implemented types
Mixed-in types
Available extensions

Constructors

PulseF({Map<Object, dynamic>? map, required Fractal by})

Properties

by Fractal
getter/setter pair
first → dynamic
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interest int
no setterinherited
list List
getter/setter pairinherited
listeners List<dynamic Function(dynamic)>
finalinherited
listenersVoid List<dynamic Function()>
finalinherited
looking List<SinkF>
finalinherited
map Map<Object, dynamic>
getter/setter pairinherited
noInterest bool
no setterinherited
outputBy Map<Fractal, MP>
final
passed List<Fractal>
final
requests HashMap<Object, Completer>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable
no setterinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
complete(Object key, dynamic value) bool
inherited
containsKey(Object key) bool
inherited
discover(Object key) → dynamic
inherited
input(dynamic f) → dynamic
inherited
listen(dynamic fn(dynamic)) List
inherited
look(SinkF f) → void
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(dynamic fractal) → dynamic
inherited
notifyListeners() → dynamic
inherited
remove(Object key) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
request(Object key) Future
inherited
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(dynamic)) → void
inherited
unLook(SinkF f) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
inherited
operator []=(Object key, dynamic val) → void
inherited