SparkF class

Constructors

SparkF({required PulseF pulse, required MP map})

Properties

hashCode int
The hash code for this object.
no setterinherited
map MP
getter/setter pair
pulse PulseF
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
re(MP mp) SparkF
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
operator []=(String key, dynamic val) → void