Transformer class

Constructors

Transformer(Map<String, dynamic> original, Map<String, List<Segment>> preprocessed)

Properties

hashCode int
The hash code for this object.
no setterinherited
original Map<String, dynamic>
final
preprocessed Map<String, List<Segment>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

digest() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

methods Map<String, Function>
final