TransformerPreprocessor class

Constructors

TransformerPreprocessor(Map<String, String> rawTransformers)

Properties

hashCode int
The hash code for this object.
no setterinherited
preprocessed Map<String, List<Segment>>
getter/setter pair
rawTransformers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String key, String? newValue) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited