DBF class

Constructors

DBF(FDBA db)

Properties

db FDBA
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<TableF>
final

Methods

clear() → dynamic
getVar(String key) Future<String?>
init() Future<bool>
initVars() Future<TableF>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVar(String key, dynamic val) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isWeb bool
getter/setter pair
main DBF
latefinal

Static Methods

initiate(FDBA fdb) FutureOr<bool>