FR<V extends EventFractal> class

Constructors

FR(String ref)
FR.h(V ev)

Properties

future Future<V>
final
hashCode int
The hash code for this object.
no setterinherited
ref String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hn<R extends EventFractal>(R? ev) FR<R>?
n<R extends EventFractal>(String? refN) FR<R>?