FChangeNotifier class

Implemented types
Implementers

Constructors

FChangeNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
override
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debugAssertNotDisposed(FChangeNotifier notifier) bool