FReFuture<V> class
- Inheritance
- Available extensions
Properties
-
buf
← List<
int> -
no getterinherited
- bytes → Uint8List
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setterinherited
- isNull → bool
-
Available on Frac<
Object?> , provided by the FracNullExt extensionno setter - isTrue → bool
-
Available on Frac<
bool> , provided by the FracBool extensionno setter - isZero → bool
-
Available on Frac<
num?> , provided by the FracNumExt extensionno setter - ref → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ V?
-
covariantgetter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Return a
Listenablethat triggers when any of the givenListenables themselves trigger.inherited -
dispose(
) → void -
inherited
-
listen(
dynamic listener(V? val)) → dynamic -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
inherited
-
read(
Uint8List b) → Uint8List -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggle(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited