Word class

Mixed-in types
Implementers
Available extensions

Constructors

Word(String name)
factory
Word.id(String name, int id)
const

Properties

db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
hashCode int
The hash code for this object.
no setteroverride
id int
final
label String
no setter
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

ids Map<int, Word>
getter/setter pair
lastId int
getter/setter pair
map Map<String, Word>
getter/setter pair
types Map<Type, Word>
getter/setter pair

Static Methods

attach(Word word) Word

Constants

god → const Word