MF<T> mixin

Superclass constraints
Mixin applications

Properties

first → T?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interest int
no setterinherited
list List<T>
getter/setter pairinherited-setteroverride-getter
listeners List<dynamic Function(T)>
finalinherited
listenersVoid List<dynamic Function()>
finalinherited
looking List<SinkF>
finalinherited
map Map<Object, T>
getter/setter pair
noInterest bool
no setterinherited
requests HashMap<Object, Completer<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<T>
no setter

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
complete(Object key, T value) bool
containsKey(Object key) bool
discover(Object key) → dynamic
input(T f) → dynamic
inherited
listen(dynamic fn(T)) List<T>
inherited
look(SinkF f) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
inherited
notifyListeners() → dynamic
inherited
remove(Object key) → T?
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
request(Object key) Future<T>
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
inherited
unLook(SinkF f) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → T?
operator []=(Object key, T val) → void