MapF<T extends Fractal> class

Mixed-in types
Implementers

Constructors

MapF()

Properties

first → T?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interest int
no setterinherited
list List<T>
getter/setter pairinherited
listeners List<dynamic Function(T)>
finalinherited
listenersVoid List<dynamic Function()>
finalinherited
looking List<SinkF>
finalinherited
map Map<Object, T>
getter/setter pairinherited
noInterest bool
no setterinherited
requests HashMap<Object, Completer<T>>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<T>
no setterinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
cleanUp() → dynamic
complete(Object key, T event) bool
override
containsKey(Object key) bool
inherited
discover(Object key) → dynamic
inherited
input(T f) → dynamic
override
listen(dynamic fn(T)) List<T>
inherited
look(SinkF f) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
override
notifyListeners() → dynamic
inherited
remove(Object key) → T?
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
request(Object key) Future<T>
inherited
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
inherited
unLook(SinkF f) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → T?
inherited
operator []=(Object key, T val) → void
inherited