FlowF<T> mixin

Implemented types
Mixin applications

Properties

first → T?
no setter
hashCode int
The hash code for this object.
no setterinherited
interest int
no setter
list List<T>
getter/setter pair
listeners List<dynamic Function(T)>
final
listenersVoid List<dynamic Function()>
final
looking List<SinkF>
final
noInterest bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
override
input(T f) → dynamic
listen(dynamic fn(T)) List<T>
look(SinkF f) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
notifyListeners() → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
override
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
unLook(SinkF f) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited