WithNotifications mixin

Superclass constraints
Available extensions

Properties

ctrl FractalCtrl<Fractal>
no setterinherited
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
errors Frac<List<String>>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pairinherited
initiator Object?
getter/setter pairinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String
no setterinherited
keys Iterable<String>
no setterinherited
kind FKind
finalinherited
length int
no setterinherited
path String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StateF
getter/setter pairinherited
storedAt int
getter/setter pairinherited
storing Future<int>?
getter/setter pairinherited
type String
no setterinherited
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
inherited
dispose() → void
inherited
error(String e) → void
forEach(void action(String key, dynamic value)) → void
inherited
initiate() Future<bool>
inherited
map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
preload([String? type]) Future<int>
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

remove(Object? key) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
represent(String key) String
inherited
resolve(String key) → dynamic
inherited
spread(dynamic thing) → dynamic
inherited
store([MP? m]) Future<int>
inherited
synch() Future
inherited
tell(dynamic m) → dynamic
inherited
toMap() MP
inherited
toString() String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
inherited
operator []=(String key, dynamic value) → void
inherited