CatalogFractal<T extends EventFractal> class

Inheritance
Implementers
Available extensions

Constructors

CatalogFractal({EventFractal? to, Map<String, dynamic> filter = const {}, Map<String, dynamic> order = defaultOrder, FlowF<T>? source, int limit = 0, FKind kind = FKind.basic, bool onlyLocal = false})
CatalogFractal.fromMap(MP d)

Properties

accountInteraction Future<InteractionFractal>
latefinalinherited
content String
finalinherited
contents List
latefinalinherited
createdAt int
getter/setter pairinherited
createdDate DateTime
no setterinherited
ctrl CatalogCtrl<CatalogFractal<EventFractal>>
no setteroverride
d MP
getter/setter pairinherited
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
decideSync int
no setterinherited
deleteOlder bool
no setterinherited
description String?
getter/setter pairinherited
deviceInteraction Future<InteractionFractal>
latefinalinherited
display String
no setterinherited
dontStore bool
no setterinherited
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
events CatalogFractal<EventFractal>?
getter/setter pairinherited
eventsSource EventsCtrl<EventFractal>
no setterinherited
extend NodeFractal<EventFractal>?
getter/setter pairinherited
file FileF?
getter/setter pairinherited
filter Map<String, dynamic>
getter/setter pairoverride-getter
first → T?
no setterinherited
folder String?
getter/setter pairinherited
fType FileFractalType
getter/setter pairinherited
fullList List<EventFractal>
no setterinherited
hash String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pairinherited
idEvent int
getter/setter pairinherited
image ImageF?
getter/setter pairinherited
initiator Object?
getter/setter pairinherited
interactions MapEvF<InteractionFractal>
finalinherited
interest int
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isSaved bool
no setterinherited
isValid bool
getter/setter pairinherited
key String
no setterinherited
keys Iterable<String>
no setterinherited
kind FKind
finalinherited
latestSynch int
getter/setter pairinherited
length int
no setterinherited
limit int
getter/setter pairoverride-getter
linksIn List<LinkFractal>
finalinherited
linksOut List<LinkFractal>
finalinherited
list List<T>
getter/setter pairinherited
listeners List<dynamic Function(T)>
finalinherited
listenersVoid List<dynamic Function()>
finalinherited
loaded Completer<bool>
finalinherited
localPath String
getter/setter pairinherited
location Future<String>

Available on NodeFractal<EventFractal>, provided by the NodeFractalIO extension

no setter
looking List<SinkF>
finalinherited
m MapEvF<WriterFractal>
finalinherited
mode List<String>
no setter
myInteraction Future<InteractionFractal>
no setterinherited
name String
getter/setter pairinherited
noInterest bool
no setterinherited
onlyLocal bool
getter/setter pairoverride-getter
order Map<String, dynamic>
final
own bool
no setterinherited
owner NodeFractal<EventFractal>?
getter/setter pairinherited
path String
no setterinherited
price double?
getter/setter pairinherited
pubkey String
latefinalinherited
ready Future<bool>
no setterinherited
reMake ↔ dynamic Function(Map)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharable bool
no setterinherited
sharedWith List<DeviceFractal>
finalinherited
sig String
getter/setter pairinherited
sorted SortedFrac<EventFractal>
finalinherited
sortedList List<EventFractal>
no setterinherited
sortTimer Timer?
getter/setter pairinherited
source FlowF<T>?
getter/setter pairoverride-getter
state StateF
getter/setter pairinherited
storedAt int
getter/setter pairinherited
storing Future<int>?
getter/setter pairinherited
sub MapEvF<HierarchyF>
finalinherited
subscribed Completer<bool>
finalinherited
syncAt int
getter/setter pairinherited
syncDate DateTime
no setterinherited
tags List<String>
getter/setter pairinherited
title Writable
finalinherited
to Consumable?
getter/setter pairinherited
type String
no setterinherited
uis Iterable<String>
no setterinherited
url String
no setterinherited
values Iterable
no setterinherited
video FileF?
getter/setter pairinherited
whenLoaded Future<bool>
no setterinherited
whenSubscribed Future<bool>
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addInteraction(InteractionFractal f) → dynamic
inherited
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
byId(int id) → T?
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
clone(MP m) FutureOr<EventFractal>
inherited
complete() → void
inherited
construct() Future<bool>
override
constructFromMap(MP m) Future<bool>
inherited
consumable() → dynamic
inherited
consume(Consumable f) → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
inherited
discover() Future<List<NodeFractal<EventFractal>>>
inherited
dispose() → void
inherited
doHash() String
inherited
forEach(void action(String key, dynamic value)) → void
inherited
getSub<S extends EventFractal>(String name) → S?
inherited
initFS() → dynamic

Available on NodeFractal<EventFractal>, provided by the NodeFractalWeb extension

initFS() Future

Available on NodeFractal<EventFractal>, provided by the NodeFractalNativeIO extension

initiate() Future<bool>
inherited
inNode(NodeFractal<EventFractal> reNode) Future<List<EventFractal>>

Available on NodeFractal<EventFractal>, provided by the NodeInFExt extension

input(Fractal f) bool
override
interactiveFractal() → dynamic
inherited
listen(dynamic fn(T)) List<T>
inherited
listenExtended() → dynamic
inherited
look(SinkF f) → void
inherited
makeEntity(FileSystemEntity fse) Future<FractalFS?>

Available on NodeFractal<EventFractal>, provided by the NodeFractalNativeIO extension

map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

matchSource(Fractal f) bool
inherited
move() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
inherited
notifyListeners() Object?
inherited
onWrite(WriterFractal f) Future<bool>
inherited
point<E extends EventFractal>(MP m) Future<EventFractal>
inherited
preload([String? type]) Future<int>
inherited
preloadExtend() → dynamic
inherited
provide(Consumable into) → dynamic
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query() Future<void>
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

refresh() Future<void>
inherited
remove(Object? key) → dynamic
inherited
removeConnection(LinkFractal link) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
reOrder() → dynamic
represent(String key) String
inherited
resolve(String key) → dynamic
inherited
setExtendable(MP m) → dynamic
inherited
setSynched() → dynamic
inherited
signa() → dynamic
inherited
sort() → dynamic
inherited
spread(dynamic thing) → dynamic
inherited
store([MP? m]) Future<int>
inherited
synch() Future
override
tell(dynamic m, {LinkFractal? link}) Future
override
throughContent(MP map) Future<MP>
inherited
toMap() MP
inherited
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
inherited
unLook(SinkF f) → dynamic
inherited
unSynch() → dynamic
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited
write(String attr, String content) → dynamic

Available on Rewritable, provided by the RewritableExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
override
operator []=(String key, dynamic value) → void
inherited
operator []=(dynamic key, dynamic value) → void

Available on Rewritable, provided by the RewritableExt extension

Static Properties

controller CatalogCtrl<CatalogFractal<EventFractal>>
final
picking Map<String, dynamic Function(String h)?>
final
timer TimedF
final

Static Methods

pick(String h, [void miss(String h)?]) Future<EventFractal>
pickMany<E extends EventFractal>(List<String> list) Future<List<E>>
put({Map<String, dynamic> filter = const {}, Map<String, dynamic> order = defaultOrder, String source = 'event', bool includeSubTypes = true, int limit = 0, bool onlyLocal = false}) Future<CatalogFractal<EventFractal>>

Constants

defaultOrder → const Map<String, bool>