EventFractal class

Inheritance
Mixed-in types
Implementers
Available extensions

Constructors

EventFractal({int? id, String hash = '', String? pubkey, int? createdAt, String content = '', int syncAt = 0, NodeFractal<EventFractal>? owner, String sig = '', EventFractal? to, FKind kind = FKind.basic})
EventFractal.fromMap(MP d)

Properties

content String
final
contents List
latefinal
createdAt int
getter/setter pair
createdDate DateTime
no setter
ctrl EventsCtrl<EventFractal>
no setteroverride
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
decideSync int
no setter
deleteOlder bool
no setter
display String
no setter
dontStore bool
no setter
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
events CatalogFractal<EventFractal>?
getter/setter pairinherited
eventsSource EventsCtrl<EventFractal>
no setter
file FileF?
no setter
hash String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pairinherited
idEvent int
getter/setter pair
initiator Object?
getter/setter pairinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isSaved bool
no setterinherited
isValid bool
getter/setter pair
key String
no setteroverride
keys Iterable<String>
no setterinherited
kind FKind
finalinherited
length int
no setterinherited
own bool
no setter
owner NodeFractal<EventFractal>?
getter/setter pair
path String
no setteroverride
pubkey String
latefinal
ready Future<bool>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharable bool
no setter
sharedWith List<DeviceFractal>
final
sig String
getter/setter pair
state StateF
getter/setter pairinherited
storedAt int
getter/setter pairinherited
storing Future<int>?
getter/setter pairinherited
syncAt int
getter/setter pair
syncDate DateTime
no setter
to Consumable?
getter/setter pairinherited
type String
no setterinherited
uis Iterable<String>
no setter
url String
no setter
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
clone(MP m) FutureOr<EventFractal>
complete() → void
construct() Future<bool>
constructFromMap(MP m) Future<bool>
consumable() → dynamic
inherited
consume(Consumable f) → void
override
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
override
dispose() → void
inherited
doHash() String
forEach(void action(String key, dynamic value)) → void
inherited
initiate() Future<bool>
inherited
map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

move() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
preload([String? type]) Future<int>
override
provide(Consumable into) → dynamic
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

refresh() → dynamic
remove(Object? key) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
represent(String key) String
override
resolve(String key) → dynamic
inherited
setSynched() → dynamic
signa() → dynamic
inherited
spread(dynamic thing) → dynamic
inherited
store([MP? m]) Future<int>
override
synch() Future
override
tell(dynamic m, {LinkFractal? link}) Future
override
throughContent(MP map) Future<MP>
toMap() MP
override
toString() String
A string representation of this object.
override
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
override
operator []=(String key, dynamic value) → void
inherited

Static Properties

controller EventsCtrl<EventFractal>
final
storage MapEvF<EventFractal>
final

Static Methods

isHash(String h) bool