InteractionFractal class

Inheritance
Mixed-in types
Implementers
Available extensions

Constructors

InteractionFractal({EventFractal? to, NodeFractal<EventFractal>? owner, FKind kind = FKind.eternal})
InteractionFractal.fromMap(MP d)

Properties

content String
finalinherited
contents List
latefinalinherited
createdAt int
getter/setter pairinherited
createdDate DateTime
no setterinherited
ctrl InteractionCtrl<InteractionFractal>
no setteroverride
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
decideSync int
no setterinherited
deleteOlder bool
no setterinherited
display String
no setterinherited
dontStore bool
no setterinherited
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
events CatalogFractal<EventFractal>?
getter/setter pairinherited
eventsSource EventsCtrl<EventFractal>
no setterinherited
file FileF?
no setterinherited
hash String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hashData List
no setter
hasListeners bool
no setterinherited
id int
getter/setter pairinherited
idEvent int
getter/setter pairinherited
initiator Object?
getter/setter pairinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isSaved bool
no setterinherited
isValid bool
getter/setter pairinherited
key String
no setterinherited
keys Iterable<String>
no setterinherited
kind FKind
finalinherited
length int
no setterinherited
m MapEvF<WriterFractal>
finalinherited
own bool
no setterinherited
owner NodeFractal<EventFractal>?
getter/setter pairinherited
path String
no setterinherited
pubkey String
latefinalinherited
ready Future<bool>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharable bool
no setterinherited
sharedWith List<DeviceFractal>
finalinherited
sig String
getter/setter pairinherited
state StateF
getter/setter pairinherited
storedAt int
getter/setter pairinherited
storing Future<int>?
getter/setter pairinherited
syncAt int
getter/setter pairinherited
syncDate DateTime
no setterinherited
to Consumable?
getter/setter pairinherited
type String
no setterinherited
uis Iterable<String>
no setterinherited
url String
no setterinherited
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
clone(MP m) FutureOr<EventFractal>
inherited
complete() → void
inherited
construct() Future<bool>
inherited
constructFromMap(MP m) Future<bool>
inherited
consumable() → dynamic
inherited
consume(Consumable f) → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
inherited
dispose() → void
inherited
doHash() String
inherited
forEach(void action(String key, dynamic value)) → void
inherited
initiate() Future<bool>
inherited
map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

move() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
onWrite(WriterFractal f) Future<bool>
override
preload([String? type]) Future<int>
inherited
provide(Consumable into) → dynamic
override
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

refresh() → dynamic
inherited
remove(Object? key) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
represent(String key) String
inherited
resolve(String key) → dynamic
inherited
setSynched() → dynamic
inherited
signa() → dynamic
inherited
spread(dynamic thing) → dynamic
inherited
store([MP? m]) Future<int>
inherited
synch() Future
inherited
tell(dynamic m, {LinkFractal? link}) Future
inherited
throughContent(MP map) Future<MP>
inherited
toMap() MP
inherited
toString() String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited
write(String attr, String content) → dynamic

Available on Rewritable, provided by the RewritableExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
inherited
operator []=(String key, dynamic value) → void
inherited
operator []=(dynamic key, dynamic value) → void

Available on Rewritable, provided by the RewritableExt extension

Static Properties

controller InteractionCtrl<InteractionFractal>
final