NodeFractal<T extends EventFractal> class

Inheritance
Mixed-in types
Implementers
Available extensions

Constructors

NodeFractal({String name = '', EventFractal? to, double? price, int? createdAt, FKind kind = FKind.basic, MP d = const {}, NodeFractal<EventFractal>? extend, KeyPair? keyPair, List<EventFractal>? sub})
NodeFractal.fromMap(MP d)

Properties

accountInteraction Future<InteractionFractal>
latefinalinherited
content String
finalinherited
contents List
latefinalinherited
createdAt int
getter/setter pairinherited
createdDate DateTime
no setterinherited
ctrl NodeCtrl<NodeFractal<EventFractal>>
no setteroverride
d MP
getter/setter pair
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
decideSync int
no setterinherited
deleteOlder bool
no setterinherited
description String?
getter/setter pair
deviceInteraction Future<InteractionFractal>
latefinalinherited
display String
no setteroverride
dontStore bool
no setterinherited
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
events CatalogFractal<EventFractal>?
getter/setter pairinherited
eventsSource EventsCtrl<EventFractal>
no setterinherited
extend NodeFractal<EventFractal>?
getter/setter pairinherited
file FileF?
getter/setter pairoverride-getter
filter Map<String, dynamic>
no setterinherited
first → T?
no setterinherited
folder String?
getter/setter pair
fType FileFractalType
getter/setter pairinherited
fullList List<EventFractal>
no setter
hash String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pairinherited
idEvent int
getter/setter pairinherited
image ImageF?
getter/setter pair
initiator Object?
getter/setter pairinherited
interactions MapEvF<InteractionFractal>
finalinherited
interest int
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isSaved bool
no setterinherited
isValid bool
getter/setter pairinherited
key String
no setterinherited
keys Iterable<String>
no setterinherited
kind FKind
finalinherited
latestSynch int
getter/setter pairinherited
length int
no setterinherited
limit int
no setterinherited
linksIn List<LinkFractal>
finalinherited
linksOut List<LinkFractal>
finalinherited
list List<T>
getter/setter pairinherited
listeners List<dynamic Function(T)>
finalinherited
listenersVoid List<dynamic Function()>
finalinherited
loaded Completer<bool>
finalinherited
localPath String
getter/setter pairinherited
location Future<String>

Available on NodeFractal<EventFractal>, provided by the NodeFractalIO extension

no setter
looking List<SinkF>
finalinherited
m MapEvF<WriterFractal>
finalinherited
myInteraction Future<InteractionFractal>
no setterinherited
name String
getter/setter pair
noInterest bool
no setterinherited
onlyLocal bool
no setterinherited
order MP
no setterinherited
own bool
no setterinherited
owner NodeFractal<EventFractal>?
getter/setter pairinherited
path String
no setterinherited
price double?
getter/setter pair
pubkey String
latefinalinherited
ready Future<bool>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharable bool
no setterinherited
sharedWith List<DeviceFractal>
finalinherited
sig String
getter/setter pairinherited
sorted SortedFrac<EventFractal>
final
sortedList List<EventFractal>
no setter
sortTimer Timer?
getter/setter pair
source FlowF?
no setterinherited
state StateF
getter/setter pairinherited
storedAt int
getter/setter pairinherited
storing Future<int>?
getter/setter pairinherited
sub MapEvF<HierarchyF>
finalinherited
subscribed Completer<bool>
finalinherited
syncAt int
getter/setter pairinherited
syncDate DateTime
no setterinherited
tags List<String>
getter/setter pair
title Writable
final
to Consumable?
getter/setter pairinherited
type String
no setterinherited
uis Iterable<String>
no setteroverride
url String
no setterinherited
values Iterable
no setterinherited
video FileF?
getter/setter pair
whenLoaded Future<bool>
no setterinherited
whenSubscribed Future<bool>
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addInteraction(InteractionFractal f) → dynamic
inherited
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
byId(int id) → T?
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
clone(MP m) FutureOr<EventFractal>
inherited
complete() → void
inherited
construct() Future<bool>
inherited
constructFromMap(MP m) Future<bool>
override
consumable() → dynamic
inherited
consume(Consumable f) → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
inherited
discover() Future<List<NodeFractal<EventFractal>>>
dispose() → void
inherited
doHash() String
inherited
forEach(void action(String key, dynamic value)) → void
inherited
getSub<S extends EventFractal>(String name) → S?
inherited
initFS() → dynamic

Available on NodeFractal<EventFractal>, provided by the NodeFractalWeb extension

initFS() Future

Available on NodeFractal<EventFractal>, provided by the NodeFractalNativeIO extension

initiate() Future<bool>
override
inNode(NodeFractal<EventFractal> reNode) Future<List<EventFractal>>

Available on NodeFractal<EventFractal>, provided by the NodeInFExt extension

input(Fractal f) bool
inherited
interactiveFractal() → dynamic
inherited
listen(dynamic fn(T)) List<T>
inherited
listenExtended() → dynamic
inherited
look(SinkF f) → void
inherited
makeEntity(FileSystemEntity fse) Future<FractalFS?>

Available on NodeFractal<EventFractal>, provided by the NodeFractalNativeIO extension

map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

matchSource(Fractal f) bool
inherited
move() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
inherited
notifyListeners() Object?
inherited
onWrite(WriterFractal f) Future<bool>
override
point<E extends EventFractal>(MP m) Future<EventFractal>
preload([String? type]) Future<int>
override
preloadExtend() → dynamic
inherited
provide(Consumable into) → dynamic
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

query() Future<void>
inherited
refresh() Future<void>
inherited
remove(Object? key) → dynamic
inherited
removeConnection(LinkFractal link) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
represent(String key) String
inherited
resolve(String key) → dynamic
override
setExtendable(MP m) → dynamic
inherited
setSynched() → dynamic
inherited
signa() → dynamic
inherited
sort() → dynamic
spread(dynamic thing) → dynamic
inherited
store([MP? m]) Future<int>
inherited
synch() Future
override
tell(dynamic m, {LinkFractal? link}) Future
override
throughContent(MP map) Future<MP>
inherited
toMap() MP
inherited
toString() String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
inherited
unLook(SinkF f) → dynamic
inherited
unSynch() → dynamic
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited
write(String attr, String content) → dynamic

Available on Rewritable, provided by the RewritableExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
override
operator []=(String key, dynamic value) → void
inherited
operator []=(dynamic key, dynamic value) → void

Available on Rewritable, provided by the RewritableExt extension

Static Properties

controller NodeCtrl<NodeFractal<EventFractal>>
final
flow TypeFilter<NodeFractal<EventFractal>>
final
ui Iterable<String>
getter/setter pair