dispose method

void dispose()
inherited

Implementation

void dispose() {
  assert(FChangeNotifier.debugAssertNotDisposed(this));
  assert(
    _notificationCallStackDepth == 0,
    'The "dispose()" method on $this was called during the call to '
    '"notifyListeners()". This is likely to cause errors since it modifies '
    'the list of listeners while the list is being used.',
  );
  assert(() {
    _debugDisposed = true;
    return true;
  }());

  _listeners = _emptyListeners;
  _count = 0;
}