Writable class

Inheritance

Constructors

Writable()

Properties

buf List<int>
no getterinherited
bytes Uint8List
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value WriterFractal?
covariantgetter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
dispose() → void
inherited
listen(dynamic listener(WriterFractal? val)) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
read(Uint8List b) Uint8List
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited