WriterCtrl<T extends WriterFractal> class

Inheritance
Available extensions

Constructors

WriterCtrl({String name = 'writer', required FutureOr<T> make(dynamic), required Word extend, required List<Attr> attributes})

Properties

allAttributes → Map<String, Attr>
latefinalinherited
attributes → List<Attr>
finalinherited
controllers → List<FractalCtrl<Fractal>>
no setterinherited
db → FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf → DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dontNotify ↔ bool
getter/setter pairinherited
extend → Word
finalinherited
first → T?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
initial ↔ T
getter/setter pairinherited
initiating ↔ Completer<bool>?
getter/setter pairinherited
interest → int
no setterinherited
label → String
no setterinherited
list ↔ List<T>
getter/setter pairinherited
listeners → List<dynamic Function(T)>
finalinherited
listenersVoid → List<dynamic Function()>
finalinherited
looking → List<SinkF>
finalinherited
make ↔ FutureOr<T> Function(dynamic)
getter/setter pairinherited
name → String
finalinherited
node ↔ NodeFractal<EventFractal>
latefinalinherited
noInterest → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → SqlContext
finalinherited
sub → List<FractalCtrl<Fractal>>
finalinherited
top → List<EventsCtrl<EventFractal>>
no setterinherited
transformers ↔ Map<String, T Function(T, Rewritable)>
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
find(MP filter, {int limit = 0, MP order = const {'created_at' : true}}) → Future<Iterable<Fractal>>
inherited
hashData(MP m) → List
inherited
immutableData(MP m) → List<Object>
inherited
init() → FutureOr
inherited
input(T f) → dynamic
inherited
listen(dynamic fn(T)) → List<T>
inherited
look(SinkF f) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(T fractal) → dynamic
inherited
notifyListeners() → dynamic
inherited
preload(Iterable json) → void
inherited
put(dynamic d) → Future<T>
inherited
query(String sql, [List<Object?> parameters = const []]) → Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
toString() → String
A string representation of this object.
inherited
unListen(dynamic fn(T)) → void
inherited
unLook(SinkF f) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited