FileF class

Implementers

Constructors

FileF(String name)
factory
FileF.bytes(Uint8List bytes)
factory
FileF.fresh(String name)

Properties

bytes Uint8List
getter/setter pair
file File
final
fileName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isReady bool
no setter
loading Completer<void>?
getter/setter pair
name String
getter/setter pair
reading Completer<void>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stored Completer
final
uploaded Completer
final
url String
no setter

Methods

load() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish() Future<void>
read() → dynamic
store() Future<bool>
toString() String
A string representation of this object.
inherited
upload() Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cache Map<String, Uint8List>
final
emptyBytes Uint8List
final
host String
getter/setter pair
http String
no setter
isSecure bool
getter/setter pair
isWeb bool
getter/setter pair
main String
getter/setter pair
path String
getter/setter pair
rxpUrl RegExp
final
uploader Future<String?> Function(FileF)?
getter/setter pair
urlFile Uri Function(String u)
getter/setter pair

Static Methods

download(String name) Future<Uint8List>
eat(Map<String, dynamic> m) → dynamic
getFile(String name) → dynamic
hash(List<int> bytes) String
Creates a combined hash code for a number of objects.
override
wsUrl(String server) String