SortedFrac<T extends EventFractal> class

Inheritance

Constructors

SortedFrac(List<T> value, {dynamic onMove()?})

Properties

buf List<int>
no getterinherited
bytes Uint8List
no setterinherited
dontNotify bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
length int
no setter
onMove ↔ dynamic Function()?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<T>
covariantgetter/setter pairinherited

Methods

add(T f) → dynamic
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
dispose() → void
inherited
fromString(String s) Future<List<T>>
listen(dynamic listener(List<T> val)) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
order(T f, [int? pos]) → dynamic
read(Uint8List b) Uint8List
inherited
remove(T ev) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited