FSys class

Constructors

FSys()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ctrlMap Map<String, NodeFractal<EventFractal>>
final
ctrls NodeFractal<EventFractal>
latefinal
errors Frac<List<String>>
final
system NodeFractal<EventFractal>
latefinal

Static Methods

error(String e) → void
setup() Future