FractalSkin class

Constructors

FractalSkin({ImageF? icon, Color color = const Color.rgb(255, 17, 11), Color extraColor = const Color.rgb(255, 157, 11)})

Properties

black ↔ Color
getter/setter pair
color ↔ Color
getter/setter pair
extraColor ↔ Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon ImageF?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
white ↔ Color
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited