StoredFrac class
Constructors
- StoredFrac(String name, String iniVal)
-
factory
Properties
-
buf
← List<
int> -
no getterinherited
- bytes → Uint8List
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setterinherited
- isTrue → bool
-
Available on Frac<
bool> , provided by the FracBool extensionno setter - name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Object
-
covariantgetter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Return a
Listenablethat triggers when any of the givenListenables themselves trigger.inherited -
dispose(
) → void -
inherited
-
listen(
dynamic listener(Object val)) → dynamic -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
inherited
-
read(
Uint8List b) → Uint8List -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setValue(
dynamic val) → Future< void> -
toggle(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
map
→ Map<
String, StoredFrac> -
final