PostgresFDBA class
Constructors
Properties
- endpoint → Endpoint
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastId ↔ int
-
getter/setter pairinherited
- name ↔ String
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storing
↔ List<
Future> -
getter/setter pair
-
tables
→ Future<
List< MP> > -
no setteroverride
Methods
-
connect(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String sql, [List< Object?> parameters = const []]) → Future<bool> -
override
-
select(
String sql, [List< Object?> parameters = const []]) → Future<List< MP> > -
override
-
store(
FTransactionParams transaction) → Future< bool> -
override
-
tableIndexes(
String name) → Future< List< MP> > -
override
-
tableInfo(
String name) → Future< List< MP> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited