FractalCtrl<T extends Fractal> class
- Inheritance
- Implementers
- Available extensions
Constructors
Properties
-
allAttributes
→ Map<
String, Attr> -
latefinal
-
attributes
→ List<
Attr> -
final
-
controllers
→ List<
FractalCtrl< Fractal> > -
no setter
- db → FDBA
-
Available on FractalC<
Fractal> , provided by the FractalStoredC extensionno setter - dbf → DBF
-
Available on FractalC<
Fractal> , provided by the FractalStoredC extensionno setter - extend → Word
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
finalinherited
- initial ↔ T
-
getter/setter pair
-
initiating
↔ Completer<
bool> ? -
getter/setter pair
- label → String
-
no setterinherited
-
listeners
→ List<
dynamic Function(T)> -
final
-
make
↔ FutureOr<
T> Function(dynamic) -
getter/setter pair
- name → String
-
finalinherited
-
node
↔ NodeFractal<
EventFractal> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → SqlContext
-
final
-
sub
→ List<
FractalCtrl< Fractal> > -
final
-
top
→ List<
FractalCtrl< Fractal> > -
no setter
Methods
-
assoc(
MP attr) → String -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
from(
) → dynamic -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
init(
) → FutureOr -
initIndexes(
) → Future< void> -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
initSql(
) → Future< TableF> -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
listValues(
MP map) → Iterable< MapEntry> -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String sql, [List< Object?> parameters = const []]) → Future<bool> -
Available on FractalC<
Fractal> , provided by the FractalStoredC extension -
select(
{Iterable< String> ? fields, MP? where, int limit = 1200, Map<String, dynamic> order = const {'created_at' : true}, String group = ''}) → Future<List< MP> > -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
store(
MP map) → Future< bool> -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension -
toString(
) → String -
A string representation of this object.
inherited
-
update(
MP m, int id) → Future< bool> -
Available on FractalCtrl<
Fractal> , provided by the SqlFractalExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
map
→ Map<
String, FractalCtrl< Fractal> > -
final
Static Methods
-
where<
S extends FractalCtrl< (Fractal> >) → Iterable< S>