FChangeNotifier class
- Implemented types
-
- Implementers
Methods
-
addListener(VoidCallback listener)
→ void
-
Return a
Listenable that triggers when any of the given Listenables
themselves trigger.
override
-
dispose()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
override
-
toString()
→ String
-
A string representation of this object.
inherited