FilterF<T extends Fractal> mixin
- Superclass constraints
- Mixin applications
- Available extensions
Properties
-
ctrl
→ FractalCtrl<
Fractal> -
no setterinherited
- db → FDBA
-
Available on FractalC<
Fractal> , provided by the FractalStoredC extensionno setter - dbf → DBF
-
Available on FractalC<
Fractal> , provided by the FractalStoredC extensionno setter -
entries
→ Iterable<
MapEntry< String, dynamic> > -
no setterinherited
-
filter
→ Map<
String, dynamic> -
no setter
- first → T?
-
no setterinherited
- hash ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setterinherited
- id ↔ int
-
getter/setter pairinherited
- initiator ↔ Object?
-
getter/setter pairinherited
- interest → int
-
no setterinherited
- isEmpty → bool
-
no setterinherited
- isNotEmpty → bool
-
no setterinherited
- isSaved → bool
-
no setterinherited
- key → String
-
no setterinherited
-
keys
→ Iterable<
String> -
no setterinherited
- kind → FKind
-
finalinherited
- latestSynch ↔ int
-
getter/setter pair
- length → int
-
no setterinherited
- limit → int
-
no setter
-
list
↔ List<
T> -
getter/setter pairinherited
-
listeners
→ List<
dynamic Function(T)> -
finalinherited
-
listenersVoid
→ List<
dynamic Function()> -
finalinherited
-
loaded
→ Completer<
bool> -
final
-
looking
→ List<
SinkF> -
finalinherited
- noInterest → bool
-
no setterinherited
- onlyLocal → bool
-
no setter
- order → MP
-
no setter
- path → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → FlowF?
-
no setter
- state ↔ StateF
-
getter/setter pairinherited
- storedAt ↔ int
-
getter/setter pairinherited
-
storing
↔ Future<
int> ? -
getter/setter pairinherited
-
subscribed
→ Completer<
bool> -
final
- type → String
-
no setterinherited
- values → Iterable
-
no setterinherited
-
whenLoaded
→ Future<
bool> -
no setter
-
whenSubscribed
→ Future<
bool> -
no setter
Methods
-
addAll(
Map< String, dynamic> other) → void -
inherited
-
addEntries(
Iterable< MapEntry< newEntries) → voidString, dynamic> > -
inherited
-
addListener(
VoidCallback listener) → void -
Return a
Listenablethat triggers when any of the givenListenables themselves trigger.inherited -
byId(
int id) → T? -
cast<
RK, RV> () → Map< RK, RV> -
inherited
-
clear(
) → void -
inherited
-
containsKey(
Object? key) → bool -
inherited
-
containsValue(
Object? value) → bool -
inherited
-
delete(
) → dynamic -
inherited
-
dispose(
) → void -
override
-
forEach(
void action(String key, dynamic value)) → void -
inherited
-
initiate(
) → Future< bool> -
inherited
-
input(
Fractal f) → bool -
override
-
listen(
dynamic fn(T)) → List< T> -
override
-
look(
SinkF f) → void -
inherited
-
map<
K2, V2> (MapEntry< K2, V2> Function(String key, dynamic value)) → Map<K2, V2> -
inherited
-
match(
MP filter) → bool -
Available on FilterableF, provided by the FractalMatch extension
-
matchSource(
Fractal f) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
T fractal) → dynamic -
inherited
-
notifyListeners(
) → Object? -
inheritedoverride
-
preload(
[String? type]) → Future< int> -
inherited
-
putIfAbsent(
String key, dynamic ifAbsent()) → dynamic -
inherited
-
query(
String sql, [List< Object?> parameters = const []]) → Future<bool> -
Available on FractalC<
Fractal> , provided by the FractalStoredC extension -
query(
) → Future< void> -
refresh(
) → Future< void> -
remove(
Object? key) → dynamic -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeWhere(
bool test(String key, dynamic value)) → void -
inherited
-
represent(
String key) → String -
inherited
-
resolve(
String key) → dynamic -
inherited
-
signa(
) → dynamic -
inherited
-
spread(
dynamic thing) → dynamic -
inherited
-
store(
[MP? m]) → Future< int> -
inherited
-
synch(
) → Future -
inherited
-
tell(
dynamic m) → dynamic -
inherited
-
toMap(
) → MP -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unListen(
dynamic fn(T)) → void -
inherited
-
unLook(
SinkF f) → dynamic -
inherited
-
update(
String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic -
inherited
-
updateAll(
dynamic update(String key, dynamic value)) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → Object? -
inherited
-
operator []=(
String key, dynamic value) → void -
inherited
Static Properties
Constants
-
defaultOrder
→ const Map<
String, bool>