Fractal class

Inheritance
Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

Fractal({int? id, FKind kind = FKind.basic})
Fractal.fromMap(MP d)

Properties

ctrl FractalCtrl<Fractal>
no setter
db FDBA

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
dbf DBF

Available on FractalC<Fractal>, provided by the FractalStoredC extension

no setter
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pair
initiator Object?
getter/setter pair
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
key String
no setter
keys Iterable<String>
no setterinherited
kind FKind
final
length int
no setterinherited
path String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StateF
getter/setter pair
storedAt int
getter/setter pair
storing Future<int>?
getter/setter pair
type String
no setter
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
addListener(VoidCallback listener) → void
Return a Listenable that triggers when any of the given Listenables themselves trigger.
inherited
cast<RK, RV>() Map<RK, RV>
inherited
clear() → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
delete() → dynamic
dispose() → void
inherited
forEach(void action(String key, dynamic value)) → void
inherited
initiate() Future<bool>
map<K2, V2>(MapEntry<K2, V2> Function(String key, dynamic value)) Map<K2, V2>
inherited
match(MP filter) bool

Available on FilterableF, provided by the FractalMatch extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
preload([String? type]) Future<int>
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
inherited
query(String sql, [List<Object?> parameters = const []]) Future<bool>

Available on FractalC<Fractal>, provided by the FractalStoredC extension

remove(Object? key) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
represent(String key) String
resolve(String key) → dynamic
spread(dynamic thing) → dynamic
store([MP? m]) Future<int>
synch() Future
tell(dynamic m) → dynamic
inherited
toMap() MP
toString() String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
inherited
updateAll(dynamic update(String key, dynamic value)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
override
operator []=(String key, dynamic value) → void
inherited

Static Properties

controller FractalCtrl<Fractal>
final
idAttr Attr
final
maps Map<String, Map<String, Object>>
final
storage MapF<Fractal>
final