KeyPair class
A pair of public and private keys.
- Annotations
-
- @sealed
- @immutable
- @JsonSerializable.new()
Constructors
- KeyPair({required String publicKey, required String privateKey})
-
const
-
KeyPair.fromJson(Map<
String, dynamic> json) -
factory
- KeyPair.fromJsonString(String jsonString)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- privateKey → String
-
The private key.
final
- publicKey → String
-
The public key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this key pair to json.
-
toJsonString(
{bool pretty = false}) → String - Converts this key pair to a json string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override