File class

Constructors

File(String _filePath)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({bool recursive = false, bool exclusive = false}) Future<File>
createSync({bool recursive = false, bool exclusive = false}) → void
delete() Future<void>
exists() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsBytes() Future<Uint8List>
readAsString() Future<String>
toString() String
A string representation of this object.
inherited
writeAsBytes(Uint8List contents) Future<void>
writeAsString(String contents) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited